@@ -4,10 +4,8 @@
 #include <ctype.h>
 #include <string.h>
 
-#define OGG_OUTPUT_BUF_LENGTH  80
-
-
-#define PRINTOUT_INTERVAL       0.5
+#define OGG_OUTPUT_BUF_LENGTH 	2048
+#define PRINTOUT_INTERVAL	0.5
 
 void 
 strip_shit(char* input, int len) {
@@ -22,27 +20,24 @@ strip_shit(char* input, int len) {
 
 int 
 extract_perc(char* input, float *result) {
-	char* bpos;
-	char* bbpos;
-	char* epos;
-	char* subs;
-	int ipos;
-	int i;
+    char* bpos;
+    char* epos;
+    char* subs;
+    int ipos;
+    int i;
 
-	bbpos = strstr(input, "Encoding");
- 	if (bbpos != NULL) {
-		bpos = (char*)strchr(bbpos, '\x5b');
-		epos = (char*)strchr(bbpos, '\x25');
-		if (bpos != NULL && epos != NULL && epos > bpos) {
-			ipos = (int)(epos - bpos);
-			subs = (char*)strndup(bpos + 1, ipos - 1);
-			sscanf(subs, "%f", result);
-			return 0;
-		} else {
-			return -1;
-		}
-	}
+    bpos = (char*)strchr(input, '\x5b');
+    epos = (char*)strchr(input, '\x25');
+    if (bpos != NULL && epos != NULL && epos > bpos) {
+        ipos = (int)(epos - bpos);
+        subs = (char*)strndup(bpos + 1, ipos - 1);
+        sscanf(subs, "%f", result);
+        return 0;
+    } else {
+        return -1;
+    }
 }
+
 int
 ogg_read_stat (float *perc)
 {
