@@ -23,6 +23,8 @@ int cddbp_signon( FILE *socket )
 	int code;
 
 	buffer = get_string_piece( socket, '\n' );
+	if (buffer == NULL)
+		return -1;
 #ifdef DEBUG
 	printf( "<= %s\n", buffer );
 #endif
@@ -41,14 +43,17 @@ int cddbp_handshake( FILE *socket, const char *clientname, const char *version )
 	int code;
 
 	/* Greetings! */
+	/* <tmancill@debian.org> - no need to disclose user and hostname */
 #ifdef DEBUG
 	printf( "=> cddb hello %s %s %s %s\n",
-	        getenv( "USER" ), getenv( "HOSTNAME" ), clientname, version );
+	        "anonymous", "localhost", clientname, version );
 #endif
 	fprintf( socket, "cddb hello %s %s %s %s\n",
-	         getenv( "USER" ), getenv( "HOSTNAME" ), clientname, version );
+	         "anonymous", "localhost", clientname, version );
 
 	buffer = get_string_piece( socket, '\n' );
+	if (buffer == NULL)
+		return -1;
 #ifdef DEBUG
 	printf( "<= %s\n", buffer );
 #endif
@@ -91,6 +96,8 @@ int cddbp_query( FILE *socket, const char *disk_id, int tracknum,
 	free( buffer );
 
 	tmp = buffer = get_string_piece( socket, '\n' );
+	if (buffer == NULL)
+		return -1;
 #ifdef DEBUG
 	printf( "<= %s\n", buffer );
 #endif
@@ -164,6 +171,8 @@ int cddbp_read( FILE* socket, const char* category, const char* disk_id,
 	fprintf( socket, "cddb read %s %s\n", category, disk_id );
 
 	buffer = get_string_piece( socket, '\n' );
+	if (buffer == NULL)
+		return -1;
 #ifdef DEBUG
 	printf( "<= %s\n", buffer );
 #endif
@@ -209,6 +218,8 @@ int cddbp_stat( FILE *socket, char **result )
 	fprintf( socket, "stat\n" );
 
 	buffer = get_string_piece( socket, '\n' );
+	if (buffer == NULL)
+		return -1;
 #ifdef DEBUG
 	printf( "<= %s\n", buffer );
 #endif
@@ -263,7 +274,7 @@ int http_query( const char *server, int port, const char *URL,
 	}
 
 	sprintf( tmp, "+%d&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n", duration,
-	         getenv( "USER" ), getenv( "HOST" ), client, version );
+	         "anonymous", "localhost", client, version );
 	strcat( buffer, tmp );
 	free( tmp );
 
@@ -287,7 +298,7 @@ int http_query( const char *server, int port, const char *URL,
 	tmp = strstr( buffer, "\r\n\r\n" );
 	if ( tmp == NULL ) { /* uhoh, no empty row anywhere.... */
 		free( buffer );
-		return - 1;
+		return -1;
 	}
 	tmp += 4;
 	tmp = strdup( tmp );
@@ -373,7 +384,7 @@ int http_query_proxy( const char *server, int port, const char *proxy_server, in
 	}
 
 	sprintf( tmp, "+%d&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n", duration,
-	         getenv( "USER" ), getenv( "HOST" ), client, version );
+	         "anonymous", "localhost", client, version );
 	strcat( buffer, tmp );
 	free( tmp );
 
@@ -473,7 +484,7 @@ int http_read( const char *server, int port, const char *URL,
 
 #ifdef DEBUG
 	printf( "=> GET /%s?cmd=cddb+read+%s+%s&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	        URL, category, disk_id, getenv( "USER" ), getenv( "HOSTNAME" ), client,
+	        URL, category, disk_id, "anonymouse", "localhost", client,
 	        version );
 #endif
 
@@ -483,7 +494,7 @@ int http_read( const char *server, int port, const char *URL,
 
 	fprintf( sock,
 	         "GET /%s?cmd=cddb+read+%s+%s&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	         URL, category, disk_id, getenv( "USER" ), getenv( "HOSTNAME" ), client,
+	         URL, category, disk_id, "anonymous", "localhost", client,
 	         version );
 
 	buffer = get_ascii_file( sock );
@@ -528,7 +539,7 @@ int http_read_proxy( const char *server, int port, const char *proxy_server, int
 
 #ifdef DEBUG
 	printf( "=> GET http://%s:%i/%s?cmd=cddb+read+%s+%s&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	        server, port, URL, category, disk_id, getenv( "USER" ), getenv( "HOSTNAME" ), client,
+	        server, port, URL, category, disk_id, "anonymous", "localhost", client,
 	        version );
 #endif
 
@@ -538,7 +549,7 @@ int http_read_proxy( const char *server, int port, const char *proxy_server, int
 
 	fprintf( sock,
 	         "GET http://%s:%i/%s?cmd=cddb+read+%s+%s&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	         server, port, URL, category, disk_id, getenv( "USER" ), getenv( "HOSTNAME" ), client,
+	         server, port, URL, category, disk_id, "anonymous", "localhost", client,
 	         version );
 
 	buffer = get_ascii_file( sock );
@@ -582,14 +593,14 @@ int http_stat( const char *server, int port, const char *URL, char **result,
 
 #ifdef DEBUG
 	printf( "=> GET /%s?cmd=stat&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	        URL, getenv( "USER" ), getenv( "HOST" ), client, version );
+	        URL, "anonymous", "localhost", client, version );
 #endif
 
 	sock = socket_init( server, port );
 	if ( !sock )
 		return 999;
 	fprintf( sock, "GET /%s?cmd=stat&hello=%s+%s+%s+%s&proto=1 HTTP/1.0\r\n\r\n",
-	         URL, getenv( "USER" ), getenv( "HOST" ), client, version );
+	         URL, "anonymous", "localhost", client, version );
 
 	buffer = get_ascii_file( sock );
 #ifdef DEBUG
