@@ -18,13 +18,13 @@
 
 #include "err_dialog_handler.h"
 
-#define VERSION                     "2.3"
+#define VERSION		"2.6.1"
 
 #ifndef TRUE
-#define TRUE                     1
+#define TRUE		1
 #endif
 #ifndef FALSE
-#define FALSE                    0
+#define FALSE		0
 #endif
 
 /* =====================================================
@@ -42,6 +42,7 @@
 #define MAX_FILE_PER_DIR            1024
 #define MAX_FILE_NAME_LENGTH        512
 #define MAX_FILE_PATH_LENGTH        512
+#define MAX_TOTAL_PATH_LENGTH       (MAX_FILE_PATH_LENGTH+MAX_FILE_NAME_LENGTH)
 #define MAX_NUM_TRACK               100
 #define MAX_TITLE_LENGTH            1024
 #define MAX_ARTIST_LENGTH           1024
@@ -52,8 +53,9 @@
 #define CD                          0
 #define WAV                         1
 #define MP3                         2
+#define OGG                         3
+#define FLAC			    		4
 
-#define NUM_PTYS                    128
 /* =====================================================
  * Structures
  * ===================================================*/
@@ -126,12 +128,11 @@ typedef struct {
 		char title[ MAX_FILE_NAME_LENGTH ];
 		unsigned begin;
 		unsigned length;
-		char wav_file[ MAX_FILE_PATH_LENGTH + MAX_FILE_NAME_LENGTH ];
-		char mp3_file[ MAX_FILE_PATH_LENGTH + MAX_FILE_NAME_LENGTH ];
 		int make_wav;
 		int wav_exist;
 		int make_mp3;
 		int mp3_exist;
+		char *artist;
 	} track[ MAX_NUM_TRACK ];
 } _main_data;
 
