@@ -385,15 +385,16 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 		char *high_qual_op;
 		char *crc_op;
 	} plugins[] = {
-	    { NULL, "encode ", "ripperX_plugin-encode", "ISO Encoder v2", "-b", "", "", "-e" },
-	    { NULL, "8hz-mp3 ", "ripperX_plugin-8hz-mp3", "8hz-mp3 Encoder", "-b", "", "", "" },
-	    { NULL, "lame --nohist", "ripperX_plugin-lame", "Lame MP3 Encoder", "-b", "-v", "-V", "-h", "-p"},
-	    { NULL, "gogo", "ripperX_plugin-gogo", "GoGo MP3 Encoder", "-b", "-v 4", "", ""},
-	    { NULL, "bladeenc", "ripperX_plugin-bladeenc", "BladeEnc MP3 Encoder", "-br", "", "", "-crc" },
-	    { NULL, "xingmp3enc", "ripperX_plugin-xingmp3enc", "Xingmp3enc MP3 Encoder", "-B", "", "", "" },
-	    { NULL, "l3enc", "ripperX_plugin-l3enc", "FHG MP3 Encoder (l3enc v2.72)", "-br", "", "-hq", "-crc" },
-	    { NULL, "mp3enc", "ripperX_plugin-mp3enc", "FHG MP3 Encoder (mp3enc 3.1)", "-br", "", "-qual 9", "-crc" },
-	    { NULL, "oggenc 2>&1", "ripperX_plugin-oggenc", "OggVorbis encoder", "-b", "", "", "" }
+ 		{ NULL, "encode ", "ripperX_plugin-encode", "ISO Encoder v2", "-b", "", "", "", "-e"},
+ 		{ NULL, "8hz-mp3 ", "ripperX_plugin-8hz-mp3", "8hz-mp3 Encoder", "-b", "", "", "", ""},
+ 		{ NULL, "lame", "ripperX_plugin-lame", "Lame MP3 Encoder", "-b", "--nohist -v", "-V", "-h", "-p"},
+ 		{ NULL, "gogo", "ripperX_plugin-gogo", "GoGo MP3 Encoder", "-b", "-v 4", "", "", ""},
+ 		{ NULL, "bladeenc", "ripperX_plugin-bladeenc", "BladeEnc MP3 Encoder", "-br", "", "", "", "-crc"},
+ 		{ NULL, "xingmp3enc", "ripperX_plugin-xingmp3enc", "Xingmp3enc MP3 Encoder", "-B", "", "", "", ""},
+ 		{ NULL, "l3enc", "ripperX_plugin-l3enc", "FHG MP3 Encoder (l3enc v2.72)", "-br", "", "", "-hq", "-crc"},
+ 		{ NULL, "mp3enc", "ripperX_plugin-mp3enc", "FHG MP3 Encoder (mp3enc 3.1)", "-br", "", "", "-qual 9", "-crc"},
+ 		{ NULL, "oggenc", "ripperX_plugin-oggenc", "OggVorbis encoder", "-b", "", "", "", "" },
+ 		{ NULL, "flac", "ripperX_plugin-flac", "FLAC encoder", "", "", "", "", "" }
 	};
 
 	static struct {
@@ -434,8 +435,11 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			menu = gtk_option_menu_new();
 			encoder_menu = gtk_menu_new();
 			for ( i = 0; i < num_plugins; i++ ) {
-				plugins[ i ].menu_item = gtk_menu_item_new_with_label( plugins[ i ].description );
-				gtk_menu_append( GTK_MENU( encoder_menu ), plugins[ i ].menu_item );
+                plugins[ i ].menu_item = gtk_menu_item_new_with_label( plugins[ i ].description );
+                gtk_menu_append( GTK_MENU( encoder_menu ), plugins[ i ].menu_item );
+                if (!is_found(plugins[i].encoder)) {
+                    gtk_widget_set_sensitive(GTK_WIDGET(plugins[i].menu_item), 0);
+                }
 			}
 
 			/* set menu to current plugin */
@@ -635,19 +639,19 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 				sprintf (vbr_qual_switch, "");
 			}
 
-			snprintf( config.encoder.full_command, MAX_COMMAND_LENGTH,
+ 			if ( !strcmp( config.encoder.encoder, "flac" ) ) {
+ 			   snprintf( config.encoder.full_command, MAX_COMMAND_LENGTH, "%s", config.encoder.encoder);
+ 			} else {
+			   snprintf( config.encoder.full_command, MAX_COMMAND_LENGTH,
 			          "%s %s %s %s %s %s %s",
 			          config.encoder.encoder,
 			          bitrate_switch ,
-			          config.encoder.use_varbitrate ?
-			          plugins[ cur_plugin ].varbitrate_op : "",
-			          config.encoder.use_high_qual ?
-			          plugins[ cur_plugin ].high_qual_op : "",
-			          config.encoder.use_crc ?
-			          plugins[ cur_plugin ].crc_op : "",
-				  vbr_qual_switch,
+			          config.encoder.use_varbitrate ? plugins[ cur_plugin ].varbitrate_op : "",
+			          config.encoder.use_high_qual ? plugins[ cur_plugin ].high_qual_op : "",
+			          config.encoder.use_crc ? plugins[ cur_plugin ].crc_op : "",
+					  config.encoder.use_varbitrate ? vbr_qual_switch : "",
 			          config.encoder.extra_options );
-
+                        }
 			return 0;
 		}
 	}
@@ -1116,6 +1120,7 @@ void config_window_handler( int ops, _main_data *main_data )
 		printf( "Command : <%s>\n",
 		        config.mp3_player.command );
 #endif
+		write_config();
 		return;
 
 	case CW_CANCEL :
