@@ -94,6 +94,7 @@ void calc_stat( _main_data *main_data, _stat *stat,
 	static unsigned wav_prev_length_processed;
 	static unsigned mp3_prev_length_processed;
 	static int count;
+	static char *wav_file_path, *enc_file_path;
 	time_t cur_time;
 	unsigned wav_length_processed;
 	unsigned mp3_length_processed;
@@ -153,18 +154,19 @@ void calc_stat( _main_data *main_data, _stat *stat,
 		return;
 
 	case CALC_START :
+		create_file_names_for_track(main_data, cur_track, &wav_file_path, &enc_file_path);
 		if ( cur_type == WAV ) {
 			strcpy( stat->dest_file_name,
-			        file_name_without_path( main_data->track[ cur_track ].wav_file ) );
+			        file_name_without_path( wav_file_path ) );
 			wav_prev_length_processed = 0;
 			stat->wav_time_elapsed = 0;
 			stat->wav_track = cur_track;
 			wav_start_time = time( NULL );
 		} else {
 			strcpy( stat->src_file_name,
-			        file_name_without_path( main_data->track[ cur_track ].wav_file ) );
+			        file_name_without_path( wav_file_path ) );
 			strcpy( stat->dest_file_name,
-			        file_name_without_path( main_data->track[ cur_track ].mp3_file ) );
+			        file_name_without_path( enc_file_path ) );
 			mp3_prev_length_processed = 0;
 			stat->mp3_time_elapsed = 0;
 			stat->mp3_track = cur_track;
@@ -298,8 +300,10 @@ int lock_file( char *file_name, int is_temp )
 	           O_CREAT | O_EXCL,
 	           S_IWUSR | S_IRUSR | S_IRGRP | S_IWGRP | S_IROTH );
 
-	if ( fd >= 0 )
+	if ( fd >= 0 ) {
 		close( fd );
+		unlink( file_name );
+	}
 	else {
 		if ( errno == EEXIST )
 			if ( config.ask_when_file_exists == FALSE || is_temp == TRUE ) {
@@ -360,10 +364,11 @@ int lock_file( char *file_name, int is_temp )
 void job_starter( _main_data *main_data )
 {
 	int i, track, type, is_temp, code;
+	static char *wav_file_path, *enc_file_path;
 
 	/* Sync main_data structure with the data user has entered */
 	select_frame_handler( SF_SYNC_MAIN_DATA, 0, main_data );
-
+    create_filenames_from_format(main_data);
 	/* Reset exist flags */
 	for ( i = 0; i < main_data->num_tracks; i++ ) {
 		if ( main_data->track[ i ].make_wav )
@@ -376,27 +381,22 @@ void job_starter( _main_data *main_data )
 	type = WAV;
 	while ( find_next_job( main_data, track, WAV, &track, &type ) >= 0 ) {
 		is_temp = FALSE;
-		if ( config.auto_append_extension == TRUE )
-			if ( strstr( main_data->track[ track ].wav_file, ".wav" ) == NULL )
-				auto_append_extension( main_data->track[ track ].wav_file, WAV );
-		code = lock_file( main_data->track[ track ].wav_file, is_temp );
+		create_file_names_for_track(main_data, track, &wav_file_path, NULL);
+		code = lock_file( wav_file_path, is_temp );
 		if ( code < 0 )
 			return;
 		if ( code == 1 ) {
 			main_data->track[ track ].make_wav = FALSE;
 			main_data->track[ track ].wav_exist = TRUE;
 		}
-
 	}
 
 	if ( main_data->track[ track ].make_mp3 ) {
 		track = -1;
 		type = MP3;
 		while ( find_next_job( main_data, track, MP3, &track, &type ) >= 0 ) {
-			if ( config.auto_append_extension == TRUE )
-				if ( strstr( main_data->track[ track ].mp3_file, ".mp3" ) == NULL )
-					auto_append_extension( main_data->track[ track ].mp3_file, MP3 );
-			if ( lock_file( main_data->track[ track ].mp3_file, FALSE ) < 0 )
+			create_file_names_for_track(main_data, track, NULL, &enc_file_path);
+			if ( lock_file( enc_file_path, FALSE ) < 0 )
 				return;
 		}
 	}
@@ -412,110 +412,74 @@ void job_starter( _main_data *main_data )
 void job_finisher( _main_data *main_data )
 {
 	int i;
-	char dirstring[ MAX_COMMAND_LENGTH ];
-	char dir_name[ MAX_TITLE_LENGTH ];
-	char cmdstring[ MAX_COMMAND_LENGTH ];
-	char tmp_artist [ MAX_ARTIST_LENGTH ];
-	char tmp_title [ MAX_ARTIST_LENGTH ];
 	static char status_message[ ( MAX_FILE_PATH_LENGTH + MAX_FILE_NAME_LENGTH ) * MAX_NUM_TRACK ];
+	static char buffer[ ( MAX_FILE_PATH_LENGTH + MAX_FILE_NAME_LENGTH ) * MAX_NUM_TRACK ];
+	static char *wav_file, *enc_file;
 	int madewavs = FALSE;
 	int mademp3s = FALSE;
+	int tracksdone = 0;
+	char *artist;
 
-	strcpy( status_message, "\nWrote files: \n\n" );
-
-	/* Make a copy of disc artist and title. */
-	strncpy( tmp_artist, main_data->disc_artist, MAX_ARTIST_LENGTH);
-	strncpy( tmp_title, main_data->disc_title, MAX_ARTIST_LENGTH);
-	/* Make them suitable for use in filenames. */
-	if ( config.cddb_config.convert_spaces == TRUE ) {
-		convert_spaces( tmp_artist );
-		convert_spaces( tmp_title );
-	}
-	remove_non_unix( tmp_artist );
-	remove_non_unix( tmp_title );
+	buffer[0] = 0;
 
 	/* Clean up */
 	for ( i = 0; i < main_data->num_tracks; i++ ) {
+		create_file_names_for_track(main_data, i, &wav_file, &enc_file);
 		if ( main_data->track[ i ].wav_exist == FALSE )
-			unlink( main_data->track[ i ].wav_file );
+			unlink( wav_file );
 		else if ( main_data->track[ i ].make_wav == TRUE ) {
 			madewavs = TRUE;
-			strcat( status_message, main_data->track[ i ].wav_file );
+			strcat( status_message, wav_file );
 			strcat( status_message, "\n" );
-			if ( ( config.cddb_config.make_directories == TRUE ) && ( main_data->disc_artist[ 0 ] != 0 ) ) {
-				/* create directory hierarchy */
-				if ( parse_rx_format_string( dir_name, MAX_TITLE_LENGTH,
-					                             config.cddb_config.dir_format_string, -1, NULL, NULL, tmp_artist, tmp_title, NULL ) < 0 ) {
-					err_handler( RX_PARSING_ERR, "Check if the directory format string contains\n"
-					             "format characters other than %a or %v" );
-					snprintf( dir_name, sizeof( dir_name ), "%s - %s", tmp_artist, tmp_title );
-				}
-
-				if ( config.cddb_config.convert_spaces == TRUE )
-					convert_spaces( dir_name );
-
-				snprintf( dirstring, MAX_COMMAND_LENGTH, "%s/%s/", config.wav_path, dir_name );
-				snprintf( cmdstring, MAX_COMMAND_LENGTH , "mkdir -p \"%s\"", dirstring );
-				system( cmdstring );
-
-				/* move mp3 files in directory hierarchie */
-				snprintf( cmdstring, MAX_COMMAND_LENGTH, "mv \"%s\" \"%s\"", main_data->track[ i ].wav_file, dirstring );
-				system( cmdstring );
-			}
 		}
 		main_data->track[ i ].make_wav = FALSE;
 
-		if ( main_data->track[ i ].mp3_exist == FALSE )
-			unlink( main_data->track[ i ].mp3_file );
-		else if ( main_data->track[ i ].make_mp3 == TRUE ) {
+		if ( main_data->track[ i ].mp3_exist == TRUE &&
+			 main_data->track[ i ].make_mp3 == TRUE )
+		{
 			mademp3s = TRUE;
-			strcat( status_message, main_data->track[ i ].mp3_file );
-			strcat( status_message, "\n" );
+/*			strcat( status_message, enc_file );	*/
+/*			strcat( status_message, "\n" );					*/
 
 			/* add ID3 tag if requested */
-			if ( ( config.cddb_config.create_id3 == TRUE ) && ( main_data->disc_artist[ 0 ] != 0 ) ) {
+			if ( config.cddb_config.create_id3 == TRUE ) {
 				id3tag_t mytag;
-				FILE *fptr = NULL;
 
 				id3_cleartag( &mytag );
 				strncpy( mytag.songname, main_data->track[ i ].title, 30 );
-				strncpy( mytag.artist, main_data->disc_artist, 30 );
+				if ( !(artist = main_data->track[ i ].artist) )
+					artist = main_data->disc_artist;
+				strncpy( mytag.artist, artist, 30 );
 				strncpy( mytag.album, main_data->disc_title, 30 );
  				mytag.track = i + 1;
 				mytag.style = id3_find_cddb_category( main_data->disc_category );
 
-				fptr = fopen( main_data->track[ i ].mp3_file, "ab" );
-				if ( fptr != NULL ) {
-					id3_appendtag( fptr, &mytag );
-					fclose( fptr );
-				}
-			}
-
-			if ( ( config.cddb_config.make_directories == TRUE ) && ( main_data->disc_artist[ 0 ] != 0 ) ) {
-				/* create directory hierarchy */
-				printf( config.cddb_config.dir_format_string );
-				if ( parse_rx_format_string( dir_name, MAX_TITLE_LENGTH,
-					                             config.cddb_config.dir_format_string, -1, NULL, NULL, tmp_artist, tmp_title, NULL ) < 0 ) {
-					err_handler( RX_PARSING_ERR, "Check if the directory format string contains\n"
-					             "format characters other than %a or %v" );
-					snprintf( dir_name, sizeof( dir_name ), "%s - %s", tmp_artist, tmp_title );
-				}
-
-				if ( config.cddb_config.convert_spaces == TRUE )
-					convert_spaces( dir_name );
-
-				snprintf( dirstring, MAX_COMMAND_LENGTH, "%s/%s/", config.mp3_path, dir_name );
-				snprintf( cmdstring, MAX_COMMAND_LENGTH, "mkdir -p \"%s\"", dirstring );
-				system( cmdstring );
-
-				/* move mp3 files in directory hierarchie */
-				snprintf( cmdstring, MAX_COMMAND_LENGTH, "mv \"%s\" \"%s\"", main_data->track[ i ].mp3_file, dirstring );
-				system( cmdstring );
+                if (strstr( enc_file, ".ogg" ) == NULL) {
+                    FILE *fptr = NULL;
+
+                    fptr = fopen( enc_file, "ab" );
+                    if ( fptr != NULL ) {
+                        id3_appendtag( fptr, &mytag );
+                        fclose( fptr );
+                    }
+                } else {
+                    vorbistag(enc_file, &mytag);
+                }
+	
 			}
+			
+			//dc: strcat() is for sissies!
+	    		sprintf(&buffer[strlen(buffer)], "%d: %s\n",
+				++tracksdone, file_name_without_path(enc_file));
+		       			
 		}
 		main_data->track[ i ].make_mp3 = FALSE;
 	}
 
+	/* Generate status message */
+	sprintf(status_message, "Tracks Completed: %2d\n\nArtist: %s\nAlbum: %s\n\n%s",
+		tracksdone, main_data->disc_artist, main_data->disc_title, buffer);
+
 	/* show status pop up */
 	if ( madewavs )
 		status_handler( STAT_FINISH_WAV, status_message );
@@ -564,17 +528,11 @@ int find_next_job( _main_data *main_data,
 		if ( find_next_job( main_data, track, WAV, &temp_next, &temp_type ) >= 0 ) {
 			*next_track = temp_next;
 			*next_type = WAV;
-			if ( config.auto_append_extension == TRUE )
-				if ( strstr( main_data->track[ track ].wav_file, ".wav" ) == NULL )
-					auto_append_extension( main_data->track[ track ].wav_file, WAV );
 		} else
 			return - 1;
 	} else {
 		*next_track = track;
 		*next_type = MP3;
-		if ( config.auto_append_extension == TRUE )
-			if ( strstr( main_data->track[ track ].wav_file, ".wav" ) == NULL )
-				auto_append_extension( main_data->track[ track ].wav_file, WAV );
 
 	}
 
@@ -611,6 +569,7 @@ void job_controller( int ops, _main_data *main_data )
 	static int cur_type = -1;
 	static int wav_cur_track = -1;
 	static int mp3_cur_track = -1;
+	static int mp3_nxt_track = -1;
 	static pid_t wav_pg_pid = -1;
 	static pid_t mp3_pg_pid = -1;
 	static pid_t wav_pi_pid = -1;
@@ -619,6 +578,7 @@ void job_controller( int ops, _main_data *main_data )
 	static int mp3_read_fd;
 	static _stat stat;
 	static _main_data *saved_main_data;
+	static char *wav_file_path, *enc_file_path;
 	unsigned wav_current = 0;
 	unsigned mp3_current = 0;
 	double wav_progress;
@@ -648,6 +608,8 @@ void job_controller( int ops, _main_data *main_data )
 				job_finisher( main_data );
 				return;
 			}
+			create_file_names_for_track(main_data, mp3_cur_track,
+										&wav_file_path, &enc_file_path);
 
 			calc_stat( main_data, &stat, mp3_current,
 			           mp3_cur_track, MP3, CALC_START_SESSION );
@@ -659,8 +621,8 @@ void job_controller( int ops, _main_data *main_data )
 				                             main_data->track[ mp3_cur_track ].begin,
 				                             main_data->track[ mp3_cur_track ].length,
 				                             mp3_cur_track,
-				                             main_data->track[ mp3_cur_track ].wav_file,
-				                             main_data->track[ mp3_cur_track ].mp3_file,
+				                             wav_file_path,
+				                             enc_file_path,
 				                             &mp3_pg_pid, &mp3_pi_pid,
 				                             &mp3_read_fd ) < 0 ) {
 				job_finisher( main_data );
@@ -669,6 +631,8 @@ void job_controller( int ops, _main_data *main_data )
 			stat.encoding = TRUE;
 		} else {
 			/* found the first wav to rip */
+			create_file_names_for_track(main_data, wav_cur_track,
+										&wav_file_path, &enc_file_path);
 			calc_stat( main_data, &stat, wav_current,
 			           wav_cur_track, WAV, CALC_START_SESSION );
 			calc_stat( main_data, &stat, wav_current,
@@ -679,14 +643,21 @@ void job_controller( int ops, _main_data *main_data )
 				                             main_data->track[ wav_cur_track ].begin,
 				                             main_data->track[ wav_cur_track ].length,
 				                             wav_cur_track,
-				                             main_data->track[ wav_cur_track ].wav_file,
-				                             main_data->track[ wav_cur_track ].mp3_file,
+				                             wav_file_path,
+				                             enc_file_path,
 				                             &wav_pg_pid, &wav_pi_pid,
 				                             &wav_read_fd ) < 0 ) {
 				job_finisher( main_data );
 				return;
 			}
 			stat.ripping = TRUE;
+
+			/* Find the next track to encode if any */
+			if (find_next_job( main_data, mp3_cur_track, MP3, &mp3_nxt_track, &cur_type) < 0 ||
+				!main_data->track[ mp3_nxt_track ].make_mp3)
+			{
+				mp3_nxt_track = -1;
+			}
 		}
 
 		/* Create wav/mp3 status frame */
@@ -780,14 +751,16 @@ void job_controller( int ops, _main_data *main_data )
 						}
 
 						/*  start ripping the next track */
+						create_file_names_for_track(main_data, wav_cur_track,
+													&wav_file_path, &enc_file_path);
 						calc_stat( main_data, &stat, wav_current,
 						           wav_cur_track, WAV, CALC_START );
 						if ( start_ripping_encoding( WAV,
 							                             main_data->track[ wav_cur_track ].begin,
 							                             main_data->track[ wav_cur_track ].length,
 							                             wav_cur_track,
-							                             main_data->track[ wav_cur_track ].wav_file,
-							                             main_data->track[ wav_cur_track ].mp3_file,
+														 wav_file_path,
+														 enc_file_path,
 							                             &wav_pg_pid, &wav_pi_pid,
 							                             &wav_read_fd ) < 0 ) {
 							calc_stat( main_data, &stat, wav_current,
@@ -797,31 +770,6 @@ void job_controller( int ops, _main_data *main_data )
 							return;
 						}
 					}
-
-					/* start encoding this track if we are not encoding anything */
-					if ( ( stat.encoding == FALSE ) && main_data->track[ temp_track ].make_mp3 ) {
-						stat.encoding = TRUE;
-						mp3_cur_track = temp_track;
-
-						/*  start encoding this track */
-						calc_stat( main_data, &stat, mp3_current,
-						           mp3_cur_track, MP3, CALC_START );
-						if ( start_ripping_encoding( MP3,
-							                             main_data->track[ mp3_cur_track ].begin,
-							                             main_data->track[ mp3_cur_track ].length,
-							                             mp3_cur_track,
-							                             main_data->track[ mp3_cur_track ].wav_file,
-							                             main_data->track[ mp3_cur_track ].mp3_file,
-							                             &mp3_pg_pid, &mp3_pi_pid,
-							                             &mp3_read_fd ) < 0 ) {
-							stat.encoding = FALSE;
-							calc_stat( main_data, &stat, mp3_current,
-							           mp3_cur_track, MP3, CALC_STOP_SESSION );
-							job_controller_timeout( ( gpointer ) JC_T_STOP );
-							job_finisher( main_data );
-							return;
-						}
-					}
 				} /* end if job is finished section */
 				break;
 			} /* end rip switch */
@@ -882,20 +830,27 @@ void job_controller( int ops, _main_data *main_data )
 					main_data->track[ mp3_cur_track ].mp3_exist = TRUE;
 					/* Delete WAV file if he/she doesn't want it */
 					if ( !config.keep_wav ) {
-						if ( unlink( main_data->track[ mp3_cur_track ].wav_file ) < 0 )
-							err_handler( FILE_DELETE_ERR,
-							             main_data->track[ mp3_cur_track ].wav_file );
+					create_file_names_for_track(main_data, mp3_cur_track,
+												&wav_file_path, &enc_file_path);
+						if ( unlink( wav_file_path ) < 0 )
+							err_handler( FILE_DELETE_ERR, wav_file_path );
 						/* Mark that it has been deleted */
 						main_data->track[ mp3_cur_track ].wav_exist = FALSE;
+						
+						/* Delete WAV work directory if this was the last WAV file,
+						and the mp3 work dir is different */
+						if (stat.tracks_remain <= 1)
+							if (strcmp(config.wav_path,config.mp3_path) != 0)
+						 		rmdir(file_path_without_name(wav_file_path));
 					}
 
 					/* find next track to encode */
 					temp_track = mp3_cur_track;
-					if ( find_next_job( main_data, mp3_cur_track, MP3, &mp3_cur_track, &cur_type ) < 0 ) {
+					if ( find_next_job( main_data, mp3_cur_track, MP3, &mp3_nxt_track, &cur_type ) < 0 ) {
 						/* All finished - no more encoding - done for good! */
 						mp3_pg_pid = -1;
 						mp3_pi_pid = -1;
-						mp3_cur_track = -1;
+						mp3_cur_track = mp3_nxt_track = -1;
 						cur_type = -1;
 						calc_stat( main_data, &stat, mp3_current,
 						           temp_track, MP3, CALC_STOP_SESSION );
@@ -905,39 +860,46 @@ void job_controller( int ops, _main_data *main_data )
 						job_finisher( main_data );
 						return;
 					}
+					mp3_cur_track = -1;
 
 					stat.tracks_done++;
 					stat.tracks_remain--;
+					stat.encoding = FALSE;
 
-					/*  start encoding the next track only if it is already finished ripping */
-					if ( !main_data->track[ mp3_cur_track ].wav_exist ) {
-						/* ripping of the next track is not finished. Lets wait for it to finish */
-						stat.encoding = FALSE;
-						return;
-					}
-
-					/* start encoding */
-					calc_stat( main_data, &stat, mp3_current,
-					           mp3_cur_track, MP3, CALC_START );
-					if ( start_ripping_encoding( MP3,
-						                             main_data->track[ mp3_cur_track ].begin,
-						                             main_data->track[ mp3_cur_track ].length,
-						                             mp3_cur_track,
-						                             main_data->track[ mp3_cur_track ].wav_file,
-						                             main_data->track[ mp3_cur_track ].mp3_file,
-						                             &mp3_pg_pid, &mp3_pi_pid,
-						                             &mp3_read_fd ) < 0 ) {
-						calc_stat( main_data, &stat, mp3_current,
-						           mp3_cur_track, MP3, CALC_STOP_SESSION );
-						job_controller_timeout( ( gpointer ) JC_T_STOP );
-						job_finisher( main_data );
-						return;
-					}
 				} /* end if job is finished section */
 				break;
 			} /* end encode switch */
 		} /* end encode progress check */
 
+		if ( !stat.encoding			&& 
+			 mp3_nxt_track != -1	&&
+			 main_data->track[ mp3_nxt_track ].wav_exist)
+		{
+
+			/* start encoding */
+			mp3_cur_track = mp3_nxt_track;
+			mp3_nxt_track = -1;
+			create_file_names_for_track(main_data, mp3_cur_track,
+										&wav_file_path, &enc_file_path);
+			calc_stat( main_data, &stat, mp3_current,
+					   mp3_cur_track, MP3, CALC_START );
+			if ( start_ripping_encoding( MP3,
+											 main_data->track[ mp3_cur_track ].begin,
+											 main_data->track[ mp3_cur_track ].length,
+											 mp3_cur_track,
+											 wav_file_path,
+											 enc_file_path,
+											 &mp3_pg_pid, &mp3_pi_pid,
+											 &mp3_read_fd ) < 0 )
+			{
+				calc_stat( main_data, &stat, mp3_current,
+						   mp3_cur_track, MP3, CALC_STOP_SESSION );
+				job_controller_timeout( ( gpointer ) JC_T_STOP );
+				job_finisher( main_data );
+			}
+			stat.encoding = TRUE;
+		}
+
 		/* end of JC_UPDATE */
 		return;
 	case JC_PAUSE :
@@ -1021,12 +983,20 @@ void job_controller( int ops, _main_data *main_data )
 		wm_status_frame_handler( WIDGET_DESTROY, WAV, &stat, msg );
 
 		if ( ( ops == JC_ABORT_ALL_DELETE ) || ( ops == JC_ABORT_DELETE ) ) {
-			if ( wav_cur_track != -1 )
-				if ( unlink( main_data->track[ wav_cur_track ].wav_file ) < 0 )
-					err_handler( FILE_DELETE_ERR, main_data->track[ wav_cur_track ].wav_file );
-			if ( mp3_cur_track != -1 )
-				if ( unlink( main_data->track[ mp3_cur_track ].mp3_file ) < 0 )
-					err_handler( FILE_DELETE_ERR, main_data->track[ mp3_cur_track ].mp3_file );
+			create_file_names_for_track(main_data, wav_cur_track,
+										&wav_file_path, NULL);
+			if ( wav_cur_track != -1 ) {
+				create_file_names_for_track(main_data, wav_cur_track,
+											&wav_file_path, &enc_file_path);
+				if ( unlink( wav_file_path ) < 0 )
+					err_handler( FILE_DELETE_ERR, wav_file_path );
+			}
+			if ( mp3_cur_track != -1 ) {
+				create_file_names_for_track(main_data, mp3_cur_track,
+											NULL, &enc_file_path);
+				if ( unlink( enc_file_path ) < 0 )
+					err_handler( FILE_DELETE_ERR, enc_file_path );
+			}
 		} else {
 			/* Mark that it exists */
 			if ( wav_cur_track != -1 )
