@@ -45,9 +45,6 @@ void ripperX_exit( GtkWidget *widget, gpointer callback_data )
 			job_controller( JC_ABORT_ALL, NULL );
 	}
 
-	/* Write configuration file */
-	write_config();
-
 	main_window_handler( WIDGET_DESTROY, NULL, NULL );
 
 	gtk_main_quit();
@@ -60,6 +57,8 @@ int main( int argc, char *argv[] )
 	gtk_set_locale();
 
 	gtk_init( &argc, &argv );
+	
+	setlocale(LC_NUMERIC, "POSIX");
 
 	ripperX_init( &main_data );
 
